@@ -4,12 +4,17 @@
  *
  * See COPYRIGHT for the status of this software
  *
- * Author: Daniel.Veillard@w3.org
+ * Author: daniel@veillard.com
  */
 
 #ifndef __XML_XPATH_INTERNALS_H__
 #define __XML_XPATH_INTERNALS_H__
 
+#if defined(WIN32) && defined(_MSC_VER)
+#include <libxml/xmlwin32version.h>
+#else
+#include <libxml/xmlversion.h>
+#endif
 #include <libxml/xpath.h>
 
 #ifdef __cplusplus
@@ -208,13 +213,12 @@ xmlChar *	  xmlXPathParseNCName		(xmlXPathParserContextPtr ctxt);
  * Debug
  */
 #ifdef LIBXML_DEBUG_ENABLED
-double xmlXPathStringEvalNumber(const xmlChar *str);
 void xmlXPathDebugDumpObject(FILE *output, xmlXPathObjectPtr cur, int depth);
 #endif
 /*
  * Existing functions
  */
-
+double xmlXPathStringEvalNumber(const xmlChar *str);
 int xmlXPathEvaluatePredicateResult(xmlXPathParserContextPtr ctxt, 
                                     xmlXPathObjectPtr res);
 void xmlXPathInit(void);
